@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11037 2018-05-13 04:32:27Z Lavender $
+# $Id: __init__.py 11070 2018-05-21 10:34:25Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-13 12:32:27 +0800 (週日, 13 五月 2018) $
-# $Revision: 11037 $
+# $Date: 2018-05-21 18:34:25 +0800 (週一, 21 五月 2018) $
+# $Revision: 11070 $
 
 import os
+import sys
 import warnings
 import logging
 
@@ -107,6 +108,7 @@ def attachSettings(settingsDict):
             'parler',
             'sortedm2m',
             'taggit',
+            'haystack',
 
             'Zephyrus.blog_extension',
             'Zephyrus.comment',
@@ -216,4 +218,38 @@ def attachSettings(settingsDict):
         formTemplates, LANDING_FORM_SETTINGS)
     settingsDict['CMS_TEMPLATES'] = extendUnique(
         cmsTemplates, LANDING_CMS_TEMPLATES)
+
+    #=========================================================================
+    # Zephyrus blog
+    if ZEPHYRUS_BLOG_ENABLE:
+        BASE_DIR = settingsDict['BASE_DIR']
+        if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
+            HAYSTACK_SETTINGS = {
+                'HAYSTACK_CONNECTIONS': {
+                    'default': {
+                        'ENGINE': (
+                            'haystack.backends.whoosh_backend.WhooshEngine'),
+                        'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
+                        # 這個在執行 rebuild index 會爆炸
+                        'EXCLUDED_INDEXES': [
+                            'aldryn_people.search_indexes.PeopleIndex'
+                        ],
+                    },
+                },
+            }
+        else:
+            HAYSTACK_SETTINGS = {
+                'HAYSTACK_CONNECTIONS': {
+                    'default': {
+                        'ENGINE': 'xapian_backend.XapianEngine',
+                        'PATH': os.path.join(BASE_DIR, 'xapian_index'),
+                        # 這個在執行 rebuild index 會爆炸
+                        'EXCLUDED_INDEXES': [
+                            'aldryn_people.search_indexes.PeopleIndex'],
+                    },
+                },
+            }
+
+        update(settingsDict, HAYSTACK_SETTINGS)
+
     
