@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: models.py 11070 2018-05-21 10:34:25Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-05-21 18:34:25 +0800 (週一, 21 五月 2018) $
+# $Revision: 11070 $
 
 from django.db import models
 from django.conf import settings
@@ -24,13 +24,20 @@ from taggit.models import Tag
 
 from Zephyrus.blog_extension import settings as _settings
 
-class MayLikePlugin(CMSPlugin):
-    limit = models.PositiveIntegerField(default=6)
+METHODS = [
+    ('or',  _('OR')),
+    ('and',  _('AND')),
+]
 
-    tag = models.ForeignKey(
+class FilterPlugin(CMSPlugin):
+    limit = models.PositiveIntegerField(_('Limit'), default=6)
+
+    filterMethod = models.CharField(
+        _('Filter Method'), max_length=3, choices=METHODS, default='or')
+
+    tag = models.ManyToManyField(
         Tag,
-        on_delete=models.CASCADE,
-        related_name='+',
+        verbose_name=_('Tag'),
         default=None,
         blank=True,
         null=True,
@@ -38,6 +45,7 @@ class MayLikePlugin(CMSPlugin):
 
     catagory = models.ForeignKey(
         Category,
+        verbose_name=_('Catagory'),
         on_delete=models.CASCADE,
         related_name='+',
         default=None,
@@ -46,7 +54,7 @@ class MayLikePlugin(CMSPlugin):
     )
 
     renderTemplate = models.CharField(
-        _('Comment Template'), max_length=150,
+        _('Render template'), max_length=150,
         choices=_settings.ZEPHYRUS_BLOG_MAYLIKE_TEMPLATES,
         default=_settings.ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE,
     )
